@@ -38,8 +38,8 @@ class Database:
             result = ast.literal_eval(json.loads(response.content))
 
             df = pd.DataFrame(result)
-
             cols = ['datetime'] + list(df.columns)
+            
             if 'T' in freq:
                 df['time'] = df['time'].astype(str)
                 df['datetime'] = df['date'] + ' ' + df['time']
@@ -49,10 +49,10 @@ class Database:
                 df['datetime'] = pd.to_datetime(df['datetime'], format='%Y%m%d')
 
             df = df[cols]
-
             df = df.set_index(keys='datetime')
-            df = df.sort_index()
             df = df[['open', 'high', 'low', 'close', 'volume']]
+            df = df.sort_index()
+
             return df
 
         else:
@@ -61,6 +61,7 @@ class Database:
                 if check_bool_dict[error] == False:
                     err_msg += error + ','
             print(err_msg)
+    
     def get_us_stock_ohlc(self, code, start_date, end_date):
 
         check_bool_dict = self.check_us_stock_ohlc_args(code, start_date, end_date)
@@ -121,7 +122,6 @@ class Database:
             result = ast.literal_eval(json_content)
 
             df = pd.DataFrame(result)
-            df = df[['date', 'code','issued_share_mil','record_date','market_cap_mil','cumulative_market_cap_mil']]
             df = df.sort_values(['date', 'market_cap_mil'], ascending=[True, False])
             df = df.reset_index(drop=True)
             return df
@@ -547,7 +547,16 @@ class Database:
         df = pd.DataFrame(result)
         df['ipo_date'] = pd.to_datetime(df['ipo_date'],format='%Y-%m-%d')
         df['ipo_date'] = df['ipo_date'].astype(str)
+
+        df['share_issued'] = df['share_issued'].astype(str)
+        df['market_capital'] = df['market_capital'].astype(str)
+
+        df['share_issued'] = df['share_issued'].str.replace('-','')
+        df['market_capital'] = df['market_capital'].str.replace('-','')
         
+        df['share_issued'] = df['share_issued'].astype(int)
+        df['market_capital'] = df['market_capital'].astype(int)
+
         return df
 
     def get_hk_ipo_hist(self):
